valid abstract method

bool valid(
  1. DateTime date
)

Returns true if the date is valid for this DateValidator.

This is the opposite of valid. Implementations that return true for invalid should also return false for valid.

Implementation

bool valid(DateTime date);