Every class abstract
Abstract class that, when extended, processes DateTime with custom logic.
See EveryWeekday, EveryDueDayMonth, EveryWeekdayCountInMonth (also WeekdayOccurrence) and EveryDayInYear for complete base implementations.
See EveryWeek, EveryMonth, EveryYear for your base implementations.
- Implementers
- Annotations
-
- @immutable
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
next(
DateTime date) → DateTime -
Returns the next instance of the given
dateconsidering this Every base process. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
previous(
DateTime date) → DateTime -
Returns the previous instance of the given
dateconsidering this Every base process. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited