next abstract method

DateTime next(
  1. DateTime date
)

Returns the next instance of the given date considering this Every base process.

If the date is a DateTime that matches the Every pattern, a new DateTime will be generated.

Implementation

DateTime next(DateTime date);