EveryAdapter<T extends Every, V extends DateValidator> class abstract

Abstract class that, when extended, processes DateTime with custom logic.

Inheritance
Implemented types
Mixed-in types
Implementers
Annotations
  • @SubtypeNaming.new(containing: 'Adapter', packageOption: PackageOption.private)
  • @SubtypeUnnaming.new(containing: 'Wrapper', packageOption: PackageOption.private)

Constructors

EveryAdapter({required T every, required V validator})
Abstract class that, when extended, processes DateTime with custom logic.
const

Properties

every → T
The base generator for this EveryAdapter.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
validator → V
The validator used by this EveryAdapter.
final

Methods

endDate(DateTime date) DateTime
Returns the previous DateTime that matches the Every pattern.
inherited
filterValidDates(Iterable<DateTime> dates) Iterable<DateTime>
Returns the valid dates for this DateValidator in dates.
inherited
invalid(DateTime date) bool
Returns true if the date is invalid for this DateValidator.
inherited
next(DateTime date) DateTime
Returns the next instance of the given date considering this Every base process.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
previous(DateTime date) DateTime
Returns the previous instance of the given date considering this Every base process.
inherited
processDate(DateTime date, DateDirection direction) DateTime
A method that processes date with custom logic.
override
startDate(DateTime date) DateTime
Returns the start date considering the given every base process. If every is a LimitedEveryDateValidator, the limit will be passed on.
inherited
toString() String
A string representation of this object.
inherited
valid(DateTime date) bool
Returns true if the date is valid for this DateValidator.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited
operator unary-() DateValidator
inherited