EveryDateValidator class abstract

A base class that represents an Every with a DateValidator.

Inheritance
Mixed-in types
Implementers

Constructors

EveryDateValidator()
A base class that represents an Every with a DateValidator.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

endDate(DateTime date) DateTime
Returns the previous DateTime that matches the Every pattern.
filterValidDates(Iterable<DateTime> dates) Iterable<DateTime>
Returns the valid dates for this DateValidator in dates.
inherited
invalid(DateTime date) bool
Returns true if the date is invalid for this DateValidator.
inherited
next(DateTime date) DateTime
Returns the next instance of the given date considering this Every base process.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
previous(DateTime date) DateTime
Returns the previous instance of the given date considering this Every base process.
inherited
startDate(DateTime date) DateTime
Returns the start date considering the given every base process. If every is a LimitedEveryDateValidator, the limit will be passed on.
toString() String
A string representation of this object.
inherited
valid(DateTime date) bool
Returns true if the date is valid for this DateValidator.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited
operator unary-() DateValidator
inherited