previous method

  1. @override
DateTime previous(
  1. DateTime date
)
override

Returns the previous instance of the given date considering this Every base process.

If the date is a DateTime that matches the Every pattern, a new DateTime will be generated.

Implementation

@override
DateTime previous(DateTime date) {
  if (date.day > dueDay) {
    return _monthsDay(date, monthDelta: 0);
  } else {
    return _monthsDay(date, monthDelta: -1);
  }
}