next method

  1. @override
DateTime next(
  1. DateTime date
)
override

Returns the next instance of the given date considering this Every base process.

If the date is a DateTime that matches the Every pattern, a new DateTime will be generated.

Implementation

@override
DateTime next(DateTime date) {
  return processDate(
    LimitedOrEveryHandler.next(every, date, limit: null),
    DateDirection.next,
  );
}