startDate method

  1. @override
DateTime startDate(
  1. DateTime date
)
override

Returns the next DateTime that matches the Every pattern.

If the date is a DateTime that matches the Every pattern, it will be returned.

If the date is not a DateTime that matches the Every pattern, next will be called to generate a new one.

Implementation

@override
DateTime startDate(DateTime date) {
  return processDate(
    LimitedOrEveryHandler.startDate(every, date, limit: null),
    DateDirection.start,
  );
}