EveryMonth mixin

A representation of an Every that occurs every month.

Implemented types
Mixin applications

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addMonths(DateTime date, int months) DateTime
This mixin's implementation of Every.next and Every.previous.
addYears(DateTime date, int years) DateTime
This mixin's implementation of Every.next and Every.previous.
override
next(DateTime date) DateTime
Returns the next instance of the given date considering this Every base process.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
previous(DateTime date) DateTime
Returns the previous instance of the given date considering this Every base process.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited