previous method
Returns the previous month of the given date considering this
EveryMonth implementation.
Returns the previous instance of the given date considering this Every
base process.
Implementation
@override
DateTime previous(DateTime date) => addMonths(date, -1);