previous method
Generates the previous of the every base process.
It will skip currentCount times from the date using the
EverySkipCountWrapper.previous process.
If currentCount is null, it will be set to count.
Implementation
@override
DateTime previous(DateTime date, {DateTime? limit, int? currentCount}) {
assert(
currentCount == null || currentCount >= 0,
'currentCount must be greater than or equal to 0',
);
return processDate(
LimitedOrEveryHandler.previous(every, date, limit: limit),
DateDirection.previous,
limit: limit,
currentCount: currentCount ?? count,
);
}