next method
Returns the next instance of the given date considering the every
base process. If the date is valid for the invalidator, a new
DateTime will be returned.
Implementation
@override
DateTime next(DateTime date, {DateTime? limit}) =>
super.next(date, limit: limit);