startDate method
Returns the next DateTime that matches the every pattern and is not valid for the invalidator.
Implementation
@override
DateTime startDate(DateTime date, {DateTime? limit}) =>
super.startDate(date, limit: limit);
Returns the next DateTime that matches the every pattern and is not valid for the invalidator.
@override
DateTime startDate(DateTime date, {DateTime? limit}) =>
super.startDate(date, limit: limit);