next method

  1. @override
DateTime next(
  1. DateTime date
)
override

Returns the next week of the given date considering this EveryWeek implementation.

Returns the next instance of the given date considering this Every base process.

Implementation

@override
DateTime next(DateTime date) => addWeeks(date, 1);