previous method
Returns the previous week of the given date considering this EveryWeek
implementation.
Returns the previous instance of the given date considering this Every
base process.
Implementation
@override
DateTime previous(DateTime date) => addWeeks(date, -1);