previous method

  1. @override
DateTime previous(
  1. DateTime date
)
override

Returns the previous year of the given date considering this EveryYear implementation.

Returns the previous instance of the given date considering this Every base process.

Implementation

@override
DateTime previous(DateTime date) => addYears(date, -1);