startDate abstract method

  1. @override
DateTime startDate(
  1. DateTime date, {
  2. DateTime? limit,
})
override

Returns the start date considering the given every base process. If every is a LimitedEveryDateValidator, the limit will be passed on.

If the generated DateTime is still not able to return the first call to this function it will be called recursively. If limit is not null and the generated DateTime is past limit, a DateTimeLimitReachedException will be thrown.

Implementation

@override
DateTime startDate(DateTime date, {DateTime? limit});