LimitedEveryWrapper<T extends Every> class abstract

Abstract class that, when extended, wraps an Every generator.

Inheritance
Implemented types
Implementers

Constructors

LimitedEveryWrapper({required T every})
Abstract class that, when extended, wraps an Every generator.
const

Properties

every → T
The base generator for this EveryWrapper.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

next(DateTime date, {DateTime? limit}) DateTime
Returns the next instance of the given date considering this Every base process.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
previous(DateTime date, {DateTime? limit}) DateTime
Returns the previous instance of the given date considering this Every base process.
inherited
processDate(DateTime date, DateDirection direction, {DateTime? limit}) DateTime
A method that processes date with custom logic.
override
throwIfLimitReached(DateTime date, DateDirection direction, {required DateTime? limit}) → void
Throws a DateTimeLimitReachedException if the date has reached the limit in the given direction.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited