valid method
Returns true if the date is valid for this DateValidator.
This is the opposite of valid. Implementations that return true for invalid should also return false for valid.
Implementation
@override
bool valid(DateTime date) {
if (exact) return date.day == dueDay;
final actualDay = dueDay.clamp(
date.firstDayOfMonth.day,
date.lastDayOfMonth.day,
);
return date.day == actualDay;
}