Returns the next instance of the given date considering this Every base process.
date
If the date is a DateTime that matches the Every pattern, a new DateTime will be generated.
DateTime next(DateTime date);