ExactEvery constructor
const
ExactEvery({
- bool exact = false,
A class to save a truncated generator of DateTimes.
This version of Every is used to generate a DateTime truncated to a specific period, such as a week, month, or year.
This can make it easier to work with specific dates that match a particular pattern, such as the last day of the month or similar.
Implementation
const ExactEvery({super.exact});